# RAIMAD

RAIMAD Astronomical Instrument MAsk Designer

![RAIMAD banner](img/raimad-banner.png)

Read the documentation at [RAIDOC](https://maybeetree.github.io/raidoc/).

Browse RAIMAD packages at [RAIDEX](https://maybeetree.github.io/raidex/).

PyPI page: <https://pypi.org/project/raimad/>

## License

RAIMAD is free software: you can redistribute it and/or modify it under
the terms of the GNU General Public License as published by the Free Software
Foundation, version 3 of the License only.

RAIMAD is distributed in the hope that it will be useful, but WITHOUT ANY
WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
PARTICULAR PURPOSE. See the GNU General Public License for more details.

You should have received a copy of the GNU General Public License along with
RAIMAD. If not, see <https://www.gnu.org/licenses/>. 

---

Copyright (c) 2024, maybetree.

